import {
  SnippetCheckIcon
} from "./chunk-WYI4TFB3.mjs";
import {
  SnippetCopyIcon
} from "./chunk-T3MWFARI.mjs";
import {
  useSnippet
} from "./chunk-ZA6GZVQU.mjs";

// src/snippet.tsx
import { forwardRef } from "@nextui-org/system";
import { clsx } from "@nextui-org/shared-utils";
import { Tooltip } from "@nextui-org/tooltip";
import { useCallback, useMemo } from "react";
import { jsx, jsxs } from "react/jsx-runtime";
var Snippet = forwardRef((props, ref) => {
  const {
    Component,
    domRef,
    children,
    slots,
    styles,
    copied,
    copyIcon = /* @__PURE__ */ jsx(SnippetCopyIcon, {}),
    checkIcon = /* @__PURE__ */ jsx(SnippetCheckIcon, {}),
    symbolBefore,
    disableCopy,
    disableTooltip,
    hideSymbol,
    hideCopyButton,
    tooltipProps,
    isMultiLine,
    focusProps,
    onCopy,
    getSnippetProps
  } = useSnippet({ ref, ...props });
  const TooltipContent = useCallback(
    ({ children: children2 }) => /* @__PURE__ */ jsx(Tooltip, { ...tooltipProps, children: children2 }),
    [...Object.values(tooltipProps)]
  );
  const contents = useMemo(() => {
    if (hideCopyButton) {
      return null;
    }
    const copyButton = /* @__PURE__ */ jsx(
      "button",
      {
        className: slots.copy({
          class: clsx(disableCopy && "opacity-50 cursor-not-allowed", styles == null ? void 0 : styles.copy)
        }),
        onClick: onCopy,
        ...focusProps,
        children: copied ? checkIcon : copyIcon
      }
    );
    if (disableTooltip) {
      return copyButton;
    }
    return /* @__PURE__ */ jsx(TooltipContent, { children: copyButton });
  }, [
    slots,
    styles == null ? void 0 : styles.copy,
    copied,
    checkIcon,
    copyIcon,
    onCopy,
    TooltipContent,
    disableCopy,
    disableTooltip,
    hideCopyButton
  ]);
  const preContent = useMemo(() => {
    if (isMultiLine && children && Array.isArray(children)) {
      return /* @__PURE__ */ jsx("div", { className: "flex flex-col", children: children.map((t, index) => /* @__PURE__ */ jsxs("pre", { className: slots.pre({ class: styles == null ? void 0 : styles.pre }), children: [
        !hideSymbol && /* @__PURE__ */ jsx("span", { className: "select-none", children: symbolBefore }),
        t
      ] }, `${index}-${t}`)) });
    }
    return /* @__PURE__ */ jsxs("pre", { className: slots.pre({ class: styles == null ? void 0 : styles.pre }), children: [
      !hideSymbol && /* @__PURE__ */ jsx("span", { className: "select-none", children: symbolBefore }),
      children
    ] });
  }, [children, hideSymbol, isMultiLine, symbolBefore, styles == null ? void 0 : styles.pre, slots]);
  return /* @__PURE__ */ jsxs(Component, { ref: domRef, ...getSnippetProps(), children: [
    preContent,
    contents
  ] });
});
Snippet.displayName = "NextUI.Snippet";
var snippet_default = Snippet;

export {
  snippet_default
};
