// src/use-snippet.ts
import { snippet } from "@nextui-org/theme";
import { mapPropsVariants } from "@nextui-org/system";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx } from "@nextui-org/shared-utils";
import { useClipboard } from "@nextui-org/use-clipboard";
import { useFocusRing } from "@react-aria/focus";
import { useMemo, useCallback } from "react";
function useSnippet(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, snippet.variantKeys);
  const {
    ref,
    as,
    children,
    symbol = "$",
    styles,
    timeout,
    copyIcon,
    checkIcon,
    disableCopy = false,
    disableTooltip = false,
    hideCopyButton = false,
    autoFocus = false,
    hideSymbol = false,
    onCopy: onCopyProp,
    tooltipProps = {
      offset: 15,
      content: "Copy to clipboard",
      variant: originalProps == null ? void 0 : originalProps.variant,
      color: originalProps == null ? void 0 : originalProps.color,
      isDisabled: disableCopy
    },
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const { copy, copied } = useClipboard({ timeout });
  const isMultiLine = children && Array.isArray(children);
  const { isFocusVisible, focusProps } = useFocusRing({
    autoFocus
  });
  const slots = useMemo(
    () => snippet({
      ...variantProps,
      isFocusVisible
    }),
    [...Object.values(variantProps), isFocusVisible]
  );
  const symbolBefore = useMemo(() => {
    if (!symbol || typeof symbol !== "string")
      return symbol;
    const str = symbol.trim();
    return str ? `${str} ` : "";
  }, [symbol]);
  const baseStyles = clsx(styles == null ? void 0 : styles.base, className);
  const getSnippetProps = useCallback(
    () => ({
      className: slots.base({
        class: baseStyles
      }),
      ...otherProps
    }),
    [slots, baseStyles, isMultiLine, otherProps]
  );
  const onCopy = useCallback(() => {
    if (disableCopy) {
      return;
    }
    let value = "";
    if (typeof children === "string") {
      value = children;
    } else if (Array.isArray(children)) {
      value = children.join("\n");
    }
    copy(value);
    onCopyProp == null ? void 0 : onCopyProp(value);
  }, [copy, disableCopy, onCopyProp, children]);
  return {
    Component,
    as,
    domRef,
    children,
    slots,
    styles,
    copied,
    onCopy,
    copyIcon,
    checkIcon,
    symbolBefore,
    isMultiLine,
    isFocusVisible,
    focusProps,
    hideCopyButton,
    disableCopy,
    disableTooltip,
    hideSymbol,
    tooltipProps,
    getSnippetProps
  };
}

export {
  useSnippet
};
