"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Snippet: () => snippet_default,
  SnippetCheckIcon: () => SnippetCheckIcon,
  SnippetCopyIcon: () => SnippetCopyIcon,
  useSnippet: () => useSnippet
});
module.exports = __toCommonJS(src_exports);

// src/use-snippet.ts
var import_theme = require("@nextui-org/theme");
var import_system = require("@nextui-org/system");
var import_dom_utils = require("@nextui-org/dom-utils");
var import_shared_utils = require("@nextui-org/shared-utils");
var import_use_clipboard = require("@nextui-org/use-clipboard");
var import_focus = require("@react-aria/focus");
var import_react = require("react");
function useSnippet(originalProps) {
  const [props, variantProps] = (0, import_system.mapPropsVariants)(originalProps, import_theme.snippet.variantKeys);
  const {
    ref,
    as,
    children,
    symbol = "$",
    styles,
    timeout,
    copyIcon,
    checkIcon,
    disableCopy = false,
    disableTooltip = false,
    hideCopyButton = false,
    autoFocus = false,
    hideSymbol = false,
    onCopy: onCopyProp,
    tooltipProps = {
      offset: 15,
      content: "Copy to clipboard",
      variant: originalProps == null ? void 0 : originalProps.variant,
      color: originalProps == null ? void 0 : originalProps.color,
      isDisabled: disableCopy
    },
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = (0, import_dom_utils.useDOMRef)(ref);
  const { copy, copied } = (0, import_use_clipboard.useClipboard)({ timeout });
  const isMultiLine = children && Array.isArray(children);
  const { isFocusVisible, focusProps } = (0, import_focus.useFocusRing)({
    autoFocus
  });
  const slots = (0, import_react.useMemo)(
    () => (0, import_theme.snippet)({
      ...variantProps,
      isFocusVisible
    }),
    [...Object.values(variantProps), isFocusVisible]
  );
  const symbolBefore = (0, import_react.useMemo)(() => {
    if (!symbol || typeof symbol !== "string")
      return symbol;
    const str = symbol.trim();
    return str ? `${str} ` : "";
  }, [symbol]);
  const baseStyles = (0, import_shared_utils.clsx)(styles == null ? void 0 : styles.base, className);
  const getSnippetProps = (0, import_react.useCallback)(
    () => ({
      className: slots.base({
        class: baseStyles
      }),
      ...otherProps
    }),
    [slots, baseStyles, isMultiLine, otherProps]
  );
  const onCopy = (0, import_react.useCallback)(() => {
    if (disableCopy) {
      return;
    }
    let value = "";
    if (typeof children === "string") {
      value = children;
    } else if (Array.isArray(children)) {
      value = children.join("\n");
    }
    copy(value);
    onCopyProp == null ? void 0 : onCopyProp(value);
  }, [copy, disableCopy, onCopyProp, children]);
  return {
    Component,
    as,
    domRef,
    children,
    slots,
    styles,
    copied,
    onCopy,
    copyIcon,
    checkIcon,
    symbolBefore,
    isMultiLine,
    isFocusVisible,
    focusProps,
    hideCopyButton,
    disableCopy,
    disableTooltip,
    hideSymbol,
    tooltipProps,
    getSnippetProps
  };
}

// src/snippet-check-icon.tsx
var import_jsx_runtime = require("react/jsx-runtime");
var SnippetCheckIcon = () => /* @__PURE__ */ (0, import_jsx_runtime.jsx)(
  "svg",
  {
    fill: "none",
    height: "1em",
    stroke: "currentColor",
    strokeLinecap: "round",
    strokeLinejoin: "round",
    strokeWidth: 2,
    viewBox: "0 0 24 24",
    width: "1em",
    children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)("polyline", { points: "20 6 9 17 4 12" })
  }
);

// src/snippet-copy-icon.tsx
var import_jsx_runtime2 = require("react/jsx-runtime");
var SnippetCopyIcon = () => /* @__PURE__ */ (0, import_jsx_runtime2.jsx)("svg", { "aria-hidden": "true", height: "1em", role: "presentation", viewBox: "0 0 24 24", width: "1em", children: /* @__PURE__ */ (0, import_jsx_runtime2.jsx)(
  "path",
  {
    d: "M20 2H10c-1.103 0-2 .897-2 2v4H4c-1.103 0-2 .897-2 2v10c0 1.103.897 2 2 2h10c1.103 0 2-.897 2-2v-4h4c1.103 0 2-.897 2-2V4c0-1.103-.897-2-2-2zM4 20V10h10l.002 10H4zm16-6h-4v-4c0-1.103-.897-2-2-2h-4V4h10v10z",
    fill: "currentColor"
  }
) });

// src/snippet.tsx
var import_system2 = require("@nextui-org/system");
var import_shared_utils2 = require("@nextui-org/shared-utils");
var import_tooltip = require("@nextui-org/tooltip");
var import_react2 = require("react");
var import_jsx_runtime3 = require("react/jsx-runtime");
var Snippet = (0, import_system2.forwardRef)((props, ref) => {
  const {
    Component,
    domRef,
    children,
    slots,
    styles,
    copied,
    copyIcon = /* @__PURE__ */ (0, import_jsx_runtime3.jsx)(SnippetCopyIcon, {}),
    checkIcon = /* @__PURE__ */ (0, import_jsx_runtime3.jsx)(SnippetCheckIcon, {}),
    symbolBefore,
    disableCopy,
    disableTooltip,
    hideSymbol,
    hideCopyButton,
    tooltipProps,
    isMultiLine,
    focusProps,
    onCopy,
    getSnippetProps
  } = useSnippet({ ref, ...props });
  const TooltipContent = (0, import_react2.useCallback)(
    ({ children: children2 }) => /* @__PURE__ */ (0, import_jsx_runtime3.jsx)(import_tooltip.Tooltip, { ...tooltipProps, children: children2 }),
    [...Object.values(tooltipProps)]
  );
  const contents = (0, import_react2.useMemo)(() => {
    if (hideCopyButton) {
      return null;
    }
    const copyButton = /* @__PURE__ */ (0, import_jsx_runtime3.jsx)(
      "button",
      {
        className: slots.copy({
          class: (0, import_shared_utils2.clsx)(disableCopy && "opacity-50 cursor-not-allowed", styles == null ? void 0 : styles.copy)
        }),
        onClick: onCopy,
        ...focusProps,
        children: copied ? checkIcon : copyIcon
      }
    );
    if (disableTooltip) {
      return copyButton;
    }
    return /* @__PURE__ */ (0, import_jsx_runtime3.jsx)(TooltipContent, { children: copyButton });
  }, [
    slots,
    styles == null ? void 0 : styles.copy,
    copied,
    checkIcon,
    copyIcon,
    onCopy,
    TooltipContent,
    disableCopy,
    disableTooltip,
    hideCopyButton
  ]);
  const preContent = (0, import_react2.useMemo)(() => {
    if (isMultiLine && children && Array.isArray(children)) {
      return /* @__PURE__ */ (0, import_jsx_runtime3.jsx)("div", { className: "flex flex-col", children: children.map((t, index) => /* @__PURE__ */ (0, import_jsx_runtime3.jsxs)("pre", { className: slots.pre({ class: styles == null ? void 0 : styles.pre }), children: [
        !hideSymbol && /* @__PURE__ */ (0, import_jsx_runtime3.jsx)("span", { className: "select-none", children: symbolBefore }),
        t
      ] }, `${index}-${t}`)) });
    }
    return /* @__PURE__ */ (0, import_jsx_runtime3.jsxs)("pre", { className: slots.pre({ class: styles == null ? void 0 : styles.pre }), children: [
      !hideSymbol && /* @__PURE__ */ (0, import_jsx_runtime3.jsx)("span", { className: "select-none", children: symbolBefore }),
      children
    ] });
  }, [children, hideSymbol, isMultiLine, symbolBefore, styles == null ? void 0 : styles.pre, slots]);
  return /* @__PURE__ */ (0, import_jsx_runtime3.jsxs)(Component, { ref: domRef, ...getSnippetProps(), children: [
    preContent,
    contents
  ] });
});
Snippet.displayName = "NextUI.Snippet";
var snippet_default = Snippet;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Snippet,
  SnippetCheckIcon,
  SnippetCopyIcon,
  useSnippet
});
