import * as _react_types_shared from '@react-types/shared';
import * as tailwind_variants from 'tailwind-variants';
import * as react from 'react';
import * as _nextui_org_system from '@nextui-org/system';
import { HTMLNextUIProps, PropGetter } from '@nextui-org/system';
import { SnippetVariantProps, SlotsToClasses, SnippetSlots } from '@nextui-org/theme';
import { ReactRef } from '@nextui-org/shared-utils';
import { TooltipProps } from '@nextui-org/tooltip';

interface UseSnippetProps extends Omit<HTMLNextUIProps<"div">, "onCopy">, SnippetVariantProps {
    /**
     * Ref to the DOM node.
     */
    ref?: ReactRef<HTMLDivElement | null>;
    /**
     * The content of the snippet.
     * if `string[]` is passed, it will be rendered as a multi-line snippet.
     */
    children?: React.ReactNode | string | string[];
    /**
     * The symbol to show before the snippet.
     * @default "$"
     */
    symbol?: string | React.ReactNode;
    /**
     * The time in milliseconds to wait before resetting the clipboard.
     * @default 2000
     */
    timeout?: number;
    copyIcon?: React.ReactNode;
    checkIcon?: React.ReactNode;
    /**
     * Classname or List of classes to change the styles of the element.
     * if `className` is passed, it will be added to the base slot.
     *
     * @example
     * ```ts
     * <Snippet styles={{
     *    base:"base-classes",
     *    pre: "pre-classes",
     *    copy: "copy-classes",
     * }} />
     * ```
     */
    styles?: SlotsToClasses<SnippetSlots>;
    /**
     * Whether the copy button should receive focus on render.
     * @default false
     */
    autoFocus?: boolean;
    /**
     * Whether to hide the tooltip.
     * @default false
     */
    disableTooltip?: boolean;
    /**
     * Whether to disable the copy functionality.
     * @default false
     */
    disableCopy?: boolean;
    /**
     * Whether to hide the copy button.
     * @default false
     */
    hideCopyButton?: boolean;
    /**
     * Whether to hide the symbol.
     * @default false
     */
    hideSymbol?: boolean;
    /**
     * Tooltip props.
     */
    tooltipProps?: TooltipProps;
    /**
     * Callback when the text is copied.
     */
    onCopy?: (value: string | string[]) => void;
}
declare function useSnippet(originalProps: UseSnippetProps): {
    Component: _nextui_org_system.As<any>;
    as: _nextui_org_system.As<any> | undefined;
    domRef: react.RefObject<HTMLDivElement>;
    children: react.ReactNode | string[];
    slots: {
        base: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        pre: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
        copy: (slotProps?: tailwind_variants.ClassProp<tailwind_variants.ClassValue> | undefined) => string;
    };
    styles: SlotsToClasses<"base" | "pre" | "copy"> | undefined;
    copied: boolean;
    onCopy: () => void;
    copyIcon: react.ReactNode;
    checkIcon: react.ReactNode;
    symbolBefore: boolean | react.ReactChild | react.ReactFragment | null;
    isMultiLine: boolean | "" | 0 | null | undefined;
    isFocusVisible: boolean;
    focusProps: _react_types_shared.DOMAttributes<_react_types_shared.FocusableElement>;
    hideCopyButton: boolean;
    disableCopy: boolean;
    disableTooltip: boolean;
    hideSymbol: boolean;
    tooltipProps: TooltipProps;
    getSnippetProps: PropGetter<Record<string, unknown>, _nextui_org_system.DOMAttributes<_nextui_org_system.DOMElement>>;
};
type UseSnippetReturn = ReturnType<typeof useSnippet>;

export { UseSnippetProps, UseSnippetReturn, useSnippet };
